@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 National CyberSecurity Center
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 HTTP collector bot
@@ -14,38 +18,34 @@ strip_lines: boolean
 http_timeout_sec: tuple of two floats or float
 """
 
-try:
-    import requests
-except ImportError:
-    requests = None
-
 from http.client import IncompleteRead
 from urllib3.exceptions import ProtocolError, ReadTimeoutError
 
 from intelmq.lib.bot import CollectorBot
-from intelmq.lib.utils import decode, create_request_session
-from intelmq.lib.exceptions import MissingDependencyError
+from intelmq.lib.mixins import HttpMixin
+from intelmq.lib.utils import decode
+
+import requests.exceptions
 
 
-class HTTPStreamCollectorBot(CollectorBot):
-
-    sighup_delay = False
+class HTTPStreamCollectorBot(CollectorBot, HttpMixin):
+    "Open a streaming connection to the URL and process data per line"
+    _sighup_delay: bool = False
+    http_password: str = None
+    http_url: str = "<insert url of feed>"
+    http_username: str = None
+    rate_limit: int = 3600
+    ssl_client_certificate: str = None  # TODO: pathlib.Path
+    strip_lines: bool = True
 
     def init(self):
-        if requests is None:
-            raise MissingDependencyError("requests")
-
-        self.set_request_parameters()
-        self.session = create_request_session(self)
-
         self.__error_count = 0
 
     def process(self):
-        self.logger.info("Connecting to stream at %r.", self.parameters.http_url)
+        self.logger.info("Connecting to stream at %r.", self.http_url)
 
         try:
-            req = self.session.get(url=self.parameters.http_url,
-                                   stream=True)
+            req = self.http_get(url=self.http_url, stream=True)
         except requests.exceptions.ConnectionError:
             self.logger.exception('Connection Failed.')
         else:
@@ -55,7 +55,7 @@ class HTTPStreamCollectorBot(CollectorBot):
 
             try:
                 for line in req.iter_lines():
-                    if self.parameters.strip_lines:
+                    if self.strip_lines:
                         line = line.strip()
 
                     if not line:
@@ -66,7 +66,7 @@ class HTTPStreamCollectorBot(CollectorBot):
 
                     report = self.new_report()
                     report.add("raw", decode(line))
-                    report.add("feed.url", self.parameters.http_url)
+                    report.add("feed.url", self.http_url)
                     self.send_message(report)
                     self.__error_count = 0
             except (requests.exceptions.ChunkedEncodingError,
@@ -74,12 +74,12 @@ class HTTPStreamCollectorBot(CollectorBot):
                     IncompleteRead,
                     ReadTimeoutError) as exc:
                 self.__error_count += 1
-                if (self.__error_count > self.parameters.error_max_retries):
+                if (self.__error_count > self.error_max_retries):
                     self.__error_count = 0
                     raise
                 else:
                     self.logger.info('Got exception %r, retrying (consecutive error count %d <= %d).',
-                                     exc, self.__error_count, self.parameters.error_max_retries)
+                                     exc, self.__error_count, self.error_max_retries)
 
             self.logger.info('Stream stopped.')
 
