@@ -1,27 +1,48 @@
+# SPDX-FileCopyrightText: 2015 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import re
 from datetime import datetime, timedelta
+from typing import Optional
 
 from dateutil import parser
 
 from intelmq.lib.bot import CollectorBot
-from intelmq.lib.utils import (parse_relative, create_request_session_from_bot,
-                               file_name_from_response, unzip)
+from intelmq.lib.mixins import HttpMixin
+from intelmq.lib.utils import (parse_relative, file_name_from_response, unzip)
 from intelmq.lib.exceptions import MissingDependencyError
 
 try:
     import rt
 except ImportError:
     rt = None
-try:
-    import requests
-except ImportError:
-    requests = None
 
 
-class RTCollectorBot(CollectorBot):
+class RTCollectorBot(CollectorBot, HttpMixin):
+    "Fetches attachments and URLs from an Request Tracker ticketing server"
+    attachment_regex: str = "\\.csv\\.zip$"  # TODO: type could be re?
+    extract_attachment: bool = True
+    extract_download: bool = True
+    http_password: str = None
+    http_username: str = None
+    password: str = "password"
+    rate_limit: int = 3600
+    search_not_older_than: str = None  # TODO: type could be something time,
+    search_owner: str = "nobody"
+    search_queue: str = "Incident Reports"
+    search_requestor: Optional[str] = None
+    search_status: str = "new"
+    search_subject_like: str = "Report"
+    set_status: str = "open"
+    ssl_client_certificate: str = None  # TODO: type should be pathlib.Path
+    take_ticket: bool = True
+    uri: str = "http://localhost/rt/REST/1.0"
+    url_regex: str = "https://dl.shadowserver.org/[a-zA-Z0-9?_-]*"  # TODO: type could be re?
+    user: str = "intelmq"
 
-    parameter_mapping = {'search_owner': 'Owner',
+    PARAMETER_MAPPING = {'search_owner': 'Owner',
                          'search_queue': 'Queue',
                          'search_requestor': 'Requestor',
                          'search_status': 'Status',
@@ -29,18 +50,16 @@ class RTCollectorBot(CollectorBot):
                          }
 
     def init(self):
-        if requests is None:
-            raise MissingDependencyError("requests")
         if rt is None:
             raise MissingDependencyError("rt")
 
-        if getattr(self.parameters, 'search_not_older_than', None):
+        if self.search_not_older_than is not None:
             try:
-                self.not_older_than = parser.parse(self.parameters.search_not_older_than)
+                self.not_older_than = parser.parse(self.search_not_older_than)
                 self.not_older_than_type = 'absolute'
             except ValueError:
                 try:
-                    self.not_older_than_relative = timedelta(minutes=parse_relative(self.parameters.search_not_older_than))
+                    self.not_older_than_relative = timedelta(minutes=parse_relative(self.search_not_older_than))
                 except ValueError:
                     self.logger.error("Parameter 'search_not_older_than' could not be parsed. "
                                       "Check your configuration.")
@@ -49,26 +68,12 @@ class RTCollectorBot(CollectorBot):
         else:
             self.not_older_than_type = False
 
-        self.set_request_parameters()
-        self.session = create_request_session_from_bot(self)
         self._parse_extract_file_parameter('extract_attachment')
         self._parse_extract_file_parameter('extract_download')
 
-        if hasattr(self.parameters, 'unzip_attachment'):
-            self.logger.warning("The parameter 'unzip_attachment' is deprecated and "
-                                "will be removed in version 3.0 in favor of the "
-                                "more generic and powerful 'extract_attachment'. "
-                                "Look at the Bots documentation for more details.")
-            if not self.extract_attachment:
-                self.extract_attachment = self.parameters.unzip_attachment
-            else:
-                self.logger.warn("Both 'extract_attachment' and the deprecated "
-                                 "'unzip_attachment' parameter are in use. Ignoring "
-                                 "the latter one.")
-
     def process(self):
-        RT = rt.Rt(self.parameters.uri, self.parameters.user,
-                   self.parameters.password)
+        RT = rt.Rt(self.uri, self.user,
+                   self.password)
         if not RT.login():
             raise ValueError('Login failed.')
 
@@ -80,8 +85,8 @@ class RTCollectorBot(CollectorBot):
         else:
             kwargs = {}
 
-        for parameter_name, rt_name in self.parameter_mapping.items():
-            parameter_value = getattr(self.parameters, parameter_name, None)
+        for parameter_name, rt_name in self.PARAMETER_MAPPING.items():
+            parameter_value = getattr(self, parameter_name, None)
             if parameter_value:
                 kwargs[rt_name] = parameter_value
 
@@ -93,19 +98,19 @@ class RTCollectorBot(CollectorBot):
             self.logger.debug('Process ticket %s.', ticket_id)
             content = 'attachment'
             success = False
-            if self.parameters.attachment_regex:
+            if self.attachment_regex:
                 for (att_id, att_name, _, _) in RT.get_attachments(ticket_id):
-                    if re.search(self.parameters.attachment_regex, att_name):
+                    if re.search(self.attachment_regex, att_name):
                         self.logger.debug('Found attachment %s: %r.',
                                           att_id, att_name)
                         success = True
                         content = 'attachment'
                         self.extract_files = self.extract_attachment
                         break
-            if not success and self.parameters.url_regex:
+            if not success and self.url_regex:
                 ticket = RT.get_history(ticket_id)[0]
                 created = ticket['Created']
-                urlmatch = re.search(self.parameters.url_regex, ticket['Content'])
+                urlmatch = re.search(self.url_regex, ticket['Content'])
                 if urlmatch:
                     content = 'url'
                     self.extract_files = self.extract_download
@@ -125,7 +130,7 @@ class RTCollectorBot(CollectorBot):
 
                 raw = attachment
             else:
-                resp = self.session.get(url=url)
+                resp = self.http_get(url)
 
                 response_code_class = resp.status_code // 100
                 if response_code_class != 2:
@@ -133,9 +138,9 @@ class RTCollectorBot(CollectorBot):
                                       url, resp.status_code, ticket_id)
                     if response_code_class == 4:
                         self.logger.debug('Server response: %r.', resp.text)
-                        if self.parameters.set_status:
-                            RT.edit_ticket(ticket_id, status=self.parameters.set_status)
-                        if self.parameters.take_ticket:
+                        if self.set_status:
+                            RT.edit_ticket(ticket_id, status=self.set_status)
+                        if self.take_ticket:
                             try:
                                 RT.take(ticket_id)
                             except rt.BadRequest:
@@ -192,13 +197,13 @@ class RTCollectorBot(CollectorBot):
                 report.add("raw", raw)
                 self.send_message(report)
 
-            if self.parameters.take_ticket:
+            if self.take_ticket:
                 try:
                     RT.take(ticket_id)
                 except rt.BadRequest:
                     self.logger.exception("Could not take ticket %s.", ticket_id)
-            if self.parameters.set_status:
-                RT.edit_ticket(ticket_id, status=self.parameters.set_status)
+            if self.set_status:
+                RT.edit_ticket(ticket_id, status=self.set_status)
 
 
 BOT = RTCollectorBot
