@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2018 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 Parameters:
@@ -12,6 +16,8 @@ from http.client import IncompleteRead
 from urllib3.exceptions import ProtocolError, ReadTimeoutError
 
 from requests.exceptions import ChunkedEncodingError, ConnectionError
+from typing import List
+
 from intelmq.lib.bot import CollectorBot
 
 try:
@@ -22,6 +28,10 @@ except ImportError:
 
 
 class ShodanStreamCollectorBot(CollectorBot):
+    "Collect the Shodan stream from the Shodan API"
+    api_key: str = "<INSERT your API key>"
+    countries: List[str] = []
+
     def init(self):
         if shodan is None:
             raise ValueError("Library 'shodan' is needed but not installed.")
@@ -31,12 +41,12 @@ class ShodanStreamCollectorBot(CollectorBot):
             if self.proxy:
                 raise ValueError('Proxies are given but shodan-python > 1.8.1 is needed for proxy support.')
             else:
-                self.api = shodan.Shodan(self.parameters.api_key)
+                self.api = shodan.Shodan(self.api_key)
         else:
-            self.api = shodan.Shodan(self.parameters.api_key,
+            self.api = shodan.Shodan(self.api_key,
                                      proxies=self.proxy)
-        if isinstance(self.parameters.countries, str):
-            self.countries = self.parameters.countries.split(',')
+        if isinstance(self.countries, str):
+            self.countries = self.countries.split(',')
 
         self.__error_count = 0
 
@@ -55,12 +65,12 @@ class ShodanStreamCollectorBot(CollectorBot):
                 ReadTimeoutError,
                 APIError) as exc:
             self.__error_count += 1
-            if (self.__error_count > self.parameters.error_max_retries):
+            if (self.__error_count > self.error_max_retries):
                 self.__error_count = 0
                 raise
             else:
                 self.logger.info('Got exception %r, retrying (consecutive error count %d <= %d).',
-                                 exc, self.__error_count, self.parameters.error_max_retries)
+                                 exc, self.__error_count, self.error_max_retries)
 
 
 BOT = ShodanStreamCollectorBot
