@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2019 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 import csv
 import io
@@ -5,10 +9,12 @@ from intelmq.lib.bot import Bot
 
 
 class CSVConverterExpertBot(Bot):
+    """Convert data to CSV"""
+    fieldnames: str = "time.source,classification.type,source.ip"  # TODO: could maybe be List[str]
+    delimiter: str = ','
 
     def init(self):
-        self.fieldnames = self.parameters.fieldnames.split(',')
-        self.delimiter = getattr(self.parameters, 'delimiter', ',')
+        self.fieldnames = self.fieldnames.split(',')
 
     def process(self):
         event = self.receive_message()
