@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # *- coding: utf-8 -*-
 """
 RFC 1918 Will Drop Local IP from a given record and a bit more.
@@ -41,10 +45,13 @@ ASNS = ASN16 + ASN32
 
 
 class RFC1918ExpertBot(Bot):
+    """Removes fields or discard events if an IP address or domain is invalid as defined in standards like RFC 1918 (invalid, local, reserved, documentation). IP address, FQDN and URL fields are supported"""
+    fields: str = "destination.ip,source.ip,source.url"  # TODO: could be List[str]
+    policy: str = "del,drop,drop"  # TODO: detto
 
     def init(self):
-        self.fields = self.parameters.fields.lower().strip().split(",")
-        self.policy = self.parameters.policy.lower().strip().split(",")
+        self.fields = self.fields.lower().strip().split(",")
+        self.policy = self.policy.lower().strip().split(",")
 
         if len(self.fields) != len(self.policy):
             raise ValueError("Length of parameters 'fields' (%d) and 'policy' (%d) is unequal."
