@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 National CyberSecurity Center
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 
 from intelmq.lib import utils
@@ -5,6 +9,7 @@ from intelmq.lib.bot import Bot
 
 
 class CIArmyParserBot(Bot):
+    """Parse the CI Army feed"""
 
     def process(self):
 
