@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 aaronkaplan
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 The source provides a JSON file with a dictionary. The keys of this dict are
@@ -14,14 +18,14 @@ from intelmq.lib.exceptions import InvalidValue
 __all__ = ['N6StompParserBot']
 mapping = {}
 mapping['amplifier']    = {"taxonomy": "vulnerable",
-                           "type": "vulnerable service",
+                           "type": "vulnerable-system",
                            "identifier": "amplifier"}
-mapping['bots']         = {"taxonomy": "malicious code",
+mapping['bots']         = {"taxonomy": "malicious-code",
                            "type": "infected-system", "identifier": "malware-generic"}
 mapping['backdoor']     = {"taxonomy": "intrusions",
-                           "type": "backdoor", "identifier": "hacked server"}
-mapping['cnc']          = {"taxonomy": "malicious code",
-                           "type": "c2server", "identifier": "c&c server"}
+                           "type": "system-compromise", "identifier": "hacked server"}
+mapping['cnc']          = {"taxonomy": "malicious-code",
+                           "type": "c2-server", "identifier": "c&c server"}
 mapping['dns-query']    = {"taxonomy": "other",
                            "type": "other", "identifier": "dns-query"}
 mapping['dos-attacker'] = {"taxonomy": "availability",
@@ -34,31 +38,31 @@ mapping['flow-anomaly'] = {"taxonomy": "other",
                            "type": "other", "identifier": "flow-anomaly"}
 mapping['fraud']        = {"taxonomy": "fraud",
                            "type": "account numbers", "identifier": "fraud"}
-mapping['leak']         = {"taxonomy": "information content security",
-                           "type": "leak", "identifier": "leak"}
-mapping['malurl']       = {"taxonomy": "malicious code",
+mapping['leak']         = {"taxonomy": "information-content-security",
+                           "type": "data-leak", "identifier": "leak"}
+mapping['malurl']       = {"taxonomy": "malicious-code",
                            "type": "exploit", "identifier": "malurl"}
-mapping['malware-action'] = {"taxonomy": "malicious code",
+mapping['malware-action'] = {"taxonomy": "malicious-code",
                              "type": "malware-configuration",
                              "identifier": "malware-configuration"}
 mapping['phish']        = {"taxonomy": "fraud",
                            "type": "phishing", "identifier": "phishing"}
 mapping['proxy']        = {"taxonomy": "other",
                            "type": "proxy", "identifier": "openproxy"}
-mapping['sandbox-url']  = {"taxonomy": "malicious code",
-                           "type": "malware", "identifier": "sandboxurl"}
+mapping['sandbox-url']  = {"taxonomy": "malicious-code",
+                           "type": "infected-system", "identifier": "sandboxurl"}
 mapping['scanning']     = {"taxonomy": "information-gathering",
                            "type": "scanner", "identifier": "scanning"}
-mapping['server-exploit'] = {"taxonomy": "malicious code",
+mapping['server-exploit'] = {"taxonomy": "malicious-code",
                              "type": "exploit", "identifier": "server-exploit"}
-mapping['spam']         = {"taxonomy": "abusive content",
+mapping['spam']         = {"taxonomy": "abusive-content",
                            "type": "spam", "identifier": "spam"}
-mapping['spam-url']     = {"taxonomy": "abusive content",
+mapping['spam-url']     = {"taxonomy": "abusive-content",
                            "type": "spam", "identifier": "spam-url"}
 mapping['tor']          = {"taxonomy": "other",
                            "type": "tor", "identifier": "tor exit node"}
-mapping['webinject']    = {"taxonomy": "malicious code",
-                           "type": "malware", "identifier": "malware"}
+mapping['webinject']    = {"taxonomy": "malicious-code",
+                           "type": "malware-distribution", "identifier": "malware"}
 mapping['vulnerable']   = {"taxonomy": "vulnerable",
                            "type": "other", "identifier": "vulnerable"}
 mapping['other']        = {"taxonomy": "other",
@@ -66,6 +70,7 @@ mapping['other']        = {"taxonomy": "other",
 
 
 class N6StompParserBot(Bot):
+    """Parse CERT.pl's n6 feed"""
 
     def process(self):
         report = self.receive_message()
