@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2015 Sebastian Wagner
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 """
 Utilities for testing intelmq bots.
@@ -6,6 +10,7 @@ The BotTestCase can be used as base class for unittests on bots. It includes
 some basic generic tests (logged errors, correct pipeline setup).
 """
 import io
+import inspect
 import json
 import os
 import re
@@ -19,48 +24,41 @@ import redis
 import intelmq.lib.message as message
 import intelmq.lib.pipeline as pipeline
 import intelmq.lib.utils as utils
-from intelmq import CONFIG_DIR, PIPELINE_CONF_FILE, RUNTIME_CONF_FILE, DEFAULTS_CONF_FILE
+from intelmq import CONFIG_DIR, RUNTIME_CONF_FILE
 
 __all__ = ['BotTestCase']
 
-BOT_CONFIG = utils.load_configuration(pkg_resources.resource_filename('intelmq',
-                                                                      'etc/defaults.conf'))
-BOT_CONFIG.update({"destination_pipeline_broker": "pythonlist",
-                   "logging_handler": "stream",
-                   "logging_path": None,
-                   "rate_limit": 0,
-                   "retry_delay": 0,
-                   "error_retry_delay": 0,
-                   "error_max_retries": 0,
-                   "redis_cache_host": "localhost",
-                   "redis_cache_port": 6379,
-                   "redis_cache_db": 4,
-                   "redis_cache_ttl": 10,
-                   "redis_cache_password": os.environ.get('INTELMQ_TEST_REDIS_PASSWORD'),
-                   "source_pipeline_broker": "pythonlist",
-                   "testing": True,
-                   })
+BOT_CONFIG = {"destination_pipeline_broker": "pythonlist",
+              "logging_handler": "stream",
+              "logging_path": None,
+              "logging_level": "DEBUG",
+              "rate_limit": 0,
+              "retry_delay": 0,
+              "error_retry_delay": 0,
+              "error_max_retries": 0,
+              "redis_cache_host": os.getenv('INTELMQ_PIPELINE_HOST', 'localhost'),
+              "redis_cache_port": 6379,
+              "redis_cache_db": 4,
+              "redis_cache_ttl": 10,
+              "redis_cache_password": os.environ.get('INTELMQ_TEST_REDIS_PASSWORD'),
+              "source_pipeline_broker": "pythonlist",
+              "testing": True,
+              }
 
 
 class Parameters(object):
     pass
 
 
-def mocked_config(bot_id='test-bot', src_name='', dst_names=(), sysconfig={}, group=None, module=None):
+def mocked_config(bot_id='test-bot', sysconfig={}, group=None, module=None):
     def mocked(conf_file):
-        if conf_file == PIPELINE_CONF_FILE:
-            return {bot_id: {"source-queue": src_name,
-                             "destination-queues": dst_names},
-                    }
-        elif conf_file == RUNTIME_CONF_FILE:
+        if conf_file == RUNTIME_CONF_FILE:
             return {bot_id: {'description': 'Instance of a bot for automated unit tests.',
                              'group': group,
                              'module': module,
                              'name': 'Test Bot',
                              'parameters': sysconfig,
                              }}
-        elif conf_file == DEFAULTS_CONF_FILE:
-            return BOT_CONFIG
         elif conf_file.startswith(CONFIG_DIR):
             confname = os.path.join('etc/', os.path.split(conf_file)[-1])
             fname = pkg_resources.resource_filename('intelmq',
@@ -73,6 +71,10 @@ def mocked_config(bot_id='test-bot', src_name='', dst_names=(), sysconfig={}, gr
     return mocked
 
 
+def mocked_get_global_settings():
+    return BOT_CONFIG
+
+
 def skip_database():
     return unittest.skipUnless(os.environ.get('INTELMQ_TEST_DATABASES'),
                                'Skipping database tests.')
@@ -88,19 +90,18 @@ def skip_redis():
                            'Skipping without running redis.')
 
 
-def skip_local_web():
-    return unittest.skipUnless(os.environ.get('INTELMQ_TEST_LOCAL_WEB'),
-                               'Skipping local web tests.')
-
-
 def skip_exotic():
     return unittest.skipUnless(os.environ.get('INTELMQ_TEST_EXOTIC'),
                                'Skipping tests requiring exotic libs.')
 
 
-def skip_travis():
-    return unittest.skipIf(os.getenv('TRAVIS') == 'true' and os.getenv('CI') == 'true',
-                           'Test disabled on travis.')
+def skip_ci():
+    return unittest.skipIf(os.getenv('CI') == 'true', 'Test disabled on CI.')
+
+
+def skip_build_environment():
+    # For test that regularly fail in build environments like local or public Open Build Service builds
+    return unittest.skipIf(os.getenv('USER') == 'abuild', 'Test disabled in Build Service.')
 
 
 class BotTestCase(object):
@@ -168,6 +169,8 @@ class BotTestCase(object):
                                     socket_timeout=BOT_CONFIG['redis_cache_ttl'],
                                     password=password,
                                     )
+        elif cls.use_cache and os.environ.get('INTELMQ_SKIP_REDIS'):
+            cls.skipTest(cls, 'Requested cache requires deactivated Redis.')
 
     harmonization = utils.load_configuration(pkg_resources.resource_filename('intelmq',
                                                                              'etc/harmonization.conf'))
@@ -203,24 +206,20 @@ class BotTestCase(object):
                                                                 queue_name.strip('_'))
                                   for queue_name in destination_queues}
 
-        config = self.sysconfig.copy()
+        config = BOT_CONFIG.copy()
+        config.update(self.sysconfig)
         config.update(parameters)
+        config['destination_queues'] = destination_queues
         self.mocked_config = mocked_config(self.bot_id,
-                                           src_name,
-                                           destination_queues,
                                            sysconfig=config,
                                            group=self.bot_type.title(),
                                            module=self.bot_reference.__module__,
                                            )
 
-        self.resulting_config = BOT_CONFIG.copy()
-        self.resulting_config.update(self.sysconfig)
-        self.resulting_config.update(parameters)
-
         self.logger = utils.log(self.bot_id,
                                 log_path=False, stream=self.log_stream,
                                 log_format_stream=utils.LOG_FORMAT,
-                                log_level=self.resulting_config['logging_level'])
+                                log_level=config['logging_level'])
         self.logger_handlers_backup = self.logger.handlers
 
         parameters = Parameters()
@@ -230,13 +229,18 @@ class BotTestCase(object):
         with mock.patch('intelmq.lib.utils.load_configuration',
                         new=self.mocked_config):
             with mock.patch('intelmq.lib.utils.log', self.get_mocked_logger(self.logger)):
-                self.bot = self.bot_reference(self.bot_id)
+                with mock.patch('intelmq.lib.utils.get_global_settings', mocked_get_global_settings):
+                    self.bot = self.bot_reference(self.bot_id)
         self.bot._Bot__stats_cache = None
 
-        self.pipe = pipeline.Pythonlist(parameters, logger=self.logger, bot=self.bot)
+        pipeline_args = {key: getattr(self, key) for key in dir(self) if not inspect.ismethod(getattr(self, key)) and (key.startswith('source_pipeline_') or key.startswith('destination_pipeline'))}
+        self.pipe = pipeline.Pythonlist(logger=self.logger, pipeline_args=pipeline_args, load_balance=self.bot.load_balance, is_multithreaded=self.bot.is_multithreaded)
         self.pipe.set_queues(parameters.source_queue, "source")
         self.pipe.set_queues(parameters.destination_queues, "destination")
 
+        self.prepare_source_queue()
+
+    def prepare_source_queue(self):
         if self.input_message is not None:
             if not isinstance(self.input_message, (list, tuple)):
                 self.input_message = [self.input_message]
@@ -253,10 +257,38 @@ class BotTestCase(object):
             if self.default_input_message:  # None for collectors
                 self.input_queue = [self.default_input_message]
 
+    def test_static_bot_check_method(self, *args, **kwargs):
+        """
+        Check if the bot's static check() method completes without errors (exceptions).
+        The return value (errors) are *not* checked.
+
+        The arbitrary parameters for this test function are needed because if a
+        mocker mocks the test class, parameters can be added.
+        See for example `intelmq.tests.bots.collectors.http.test_collector`.
+        """
+        checks = self.bot_reference.check(self.sysconfig)
+        if checks is None:
+            return
+        self.assertIsInstance(checks, (list, tuple))
+        for check in checks:
+            self.assertIsInstance(check, (list, tuple),
+                                  '%s.check returned an invalid format. '
+                                  'Return value must be a sequence of sequences.'
+                                  '' % self.bot_name)
+            self.assertEqual(len(check), 2,
+                             '%s.check returned an invalid format. '
+                             'Return value\'s inner sequence must have a length of 2.'
+                             '' % self.bot_name)
+            self.assertNotEqual(check[0].upper(), 'ERROR',
+                                '%s.check returned the error %r.'
+                                '' % (self.bot_name, check[1]))
+        raise ValueError('checks is %r' % (checks, ))
+
     def run_bot(self, iterations: int = 1, error_on_pipeline: bool = False,
                 prepare=True, parameters={},
                 allowed_error_count=0,
-                allowed_warning_count=0):
+                allowed_warning_count=0,
+                stop_bot: bool = True):
         """
         Call this method for actually doing a test run for the specified bot.
 
@@ -265,6 +297,7 @@ class BotTestCase(object):
             parameters: passed to prepare_bot
             allowed_error_count: maximum number allow allowed errors in the logs
             allowed_warning_count: maximum number allow allowed warnings in the logs
+            bot_stop: If the bot should be stopped/shut down after running it. Set to False, if you are calling this method again afterwards, as the bot shutdown destroys structures (pipeline, etc.)
         """
         if prepare:
             self.prepare_bot(parameters=parameters)
@@ -279,7 +312,8 @@ class BotTestCase(object):
                     self.bot.start(error_on_pipeline=error_on_pipeline,
                                    source_pipeline=self.pipe,
                                    destination_pipeline=self.pipe)
-                self.bot.stop(exitcode=0)
+                if stop_bot:
+                    self.bot.stop(exitcode=0)
         self.loglines_buffer = self.log_stream.getvalue()
         self.loglines = self.loglines_buffer.splitlines()
 
@@ -289,13 +323,18 @@ class BotTestCase(object):
                          'You probably need to increase the number of '
                          'iterations of `run_bot`.')
 
+        internal_queue_size = len(self.get_input_internal_queue())
+        self.assertEqual(internal_queue_size, 0,
+                         'The internal input queue is not empty, but has '
+                         f'{internal_queue_size} element(s). '
+                         'The bot did not acknowledge all messages.')
+
         """ Test if report has required fields. """
         if self.bot_type == 'collector':
             for report_json in self.get_output_queue():
                 report = message.MessageFactory.unserialize(report_json,
                                                             harmonization=self.harmonization)
                 self.assertIsInstance(report, message.Report)
-                self.assertIn('feed.name', report)
                 self.assertIn('raw', report)
                 self.assertIn('time.observation', report)
 
@@ -315,7 +354,8 @@ class BotTestCase(object):
                                      "".format(self.bot_name,
                                                self.bot_id), "INFO")
         self.assertRegexpMatchesLog("INFO - Bot is starting.")
-        self.assertLoglineEqual(-1, "Bot stopped.", "INFO")
+        if stop_bot:
+            self.assertLoglineEqual(-1, "Bot stopped.", "INFO")
 
         allowed_error_count = max(allowed_error_count, self.allowed_error_count)
         self.assertLessEqual(len(re.findall(' - ERROR - ', self.loglines_buffer)), allowed_error_count)
@@ -349,6 +389,14 @@ class BotTestCase(object):
         else:
             return []
 
+    def get_input_internal_queue(self):
+        """Returns the internal input queue of this bot which can be filled
+           with fixture data in setUp()"""
+        if self.pipe:
+            return self.pipe.state["%s-input-internal" % self.bot_id]
+        else:
+            return []
+
     def set_input_queue(self, seq):
         """Setter for the input queue of this bot"""
         self.pipe.state["%s-input" % self.bot_id] = [utils.encode(text) for
@@ -363,10 +411,13 @@ class BotTestCase(object):
         return [utils.decode(text) for text in chain(*[self.pipe.state[x] for x in self.pipe.destination_queues[path]])]
         # return [utils.decode(text) for text in self.pipe.state["%s-output" % self.bot_id]]
 
-    def test_bot_name(self):
+    def test_bot_name(self, *args, **kwargs):
         """
         Test if Bot has a valid name.
         Must be CamelCase and end with CollectorBot etc.
+
+        Accept arbitrary arguments in case the test methods get mocked
+        and get some additional arguments. All arguments are ignored.
         """
         counter = 0
         for type_name, type_match in self.bot_types.items():
@@ -503,6 +554,10 @@ class BotTestCase(object):
             del event_dict['time.observation']
         if 'time.observation' in expected:
             del expected['time.observation']
+        if 'output' in event_dict:
+            event_dict['output'] = json.loads(event_dict['output'])
+        if 'output' in expected:
+            expected['output'] = json.loads(expected['output'])
 
         self.assertDictEqual(expected, event_dict)
 
@@ -510,6 +565,6 @@ class BotTestCase(object):
         """
         Check if the bot did consume all messages.
 
-        Execued after every test run.
+        Executed after every test run.
         """
         self.assertEqual(len(self.input_queue), 0)
