@@ -2,10 +2,12 @@
 """
 © 2020 Sebastian Wagner <wagner@cert.at>
 
-SPDX-License-Identifier: AGPL-3.0
+SPDX-License-Identifier: AGPL-3.0-or-later
 """
 from collections import OrderedDict
 from pkg_resources import resource_filename
+from pathlib import Path
+from intelmq import CONFIG_DIR
 
 from intelmq.lib.utils import load_configuration, write_configuration
 
@@ -30,6 +32,11 @@ __all__ = ['v100_dev7_modify_syntax',
            'v230_csv_parser_parameter_fix',
            'v230_deprecations',
            'v230_feed_changes',
+           'v233_feodotracker_browse',
+           'v300_bots_file_removal',
+           'v300_defaults_file_removal',
+           'v300_pipeline_file_removal',
+           'v301_deprecations',
            ]
 
 
@@ -571,6 +578,117 @@ def v230_feed_changes(defaults, runtime, harmonization, dry_run):
     return messages + ' Remove affected bots yourself.' if messages else changed, defaults, runtime, harmonization
 
 
+def v300_bots_file_removal(defaults, runtime, harmonization, dry_run):
+    """
+    Remove BOTS file
+    """
+    changed = None
+    messages = []
+    bots_file = Path(CONFIG_DIR) / "BOTS"
+    if bots_file.exists():
+        if dry_run:
+            print(f'Would now remove file {bots_file!r}.')
+        else:
+            bots_file.unlink()
+            changed = True
+    messages = ' '.join(messages)
+    return messages if messages else changed, defaults, runtime, harmonization
+
+
+def v300_defaults_file_removal(defaults, runtime, harmonization, dry_run):
+    """
+    Remove the defaults.conf file
+    """
+    changed = None
+    messages = []
+    defaults_file = Path(CONFIG_DIR) / "defaults.conf"
+    if defaults_file.exists():
+        if dry_run:
+            print(f'Would now remove file {defaults_file!r}.')
+        else:
+            defaults = load_configuration(defaults_file)
+            defaults_file.unlink()
+            changed = True
+    messages = ' '.join(messages)
+    return messages if messages else changed, defaults, runtime, harmonization
+
+
+def v233_feodotracker_browse(defaults, runtime, harmonization, dry_run):
+    """
+    Migrate Abuse.ch Feodotracker Browser feed parsing parameters
+    """
+    changed = None
+    old_feodo_columns = 'time.source,source.ip,malware.name,status,extra.SBL,source.as_name,source.geolocation.cc'
+    old_ignore_values = ',,,,Not listed,,'
+    for bot_id, bot in runtime.items():
+        # The parameters can be given as string or list of strings
+        if (bot["module"] == "intelmq.bots.parsers.html_table.parser" and 'feodo' in bot_id.lower() and
+                "columns" in bot["parameters"] and "ignore_values" in bot["parameters"] and
+                (bot["parameters"]["columns"] == old_feodo_columns or bot["parameters"]["columns"] == old_feodo_columns.split(',')) and
+                (bot["parameters"]["ignore_values"] == old_ignore_values or bot["parameters"]["ignore_values"] == old_ignore_values.split(','))):
+            bot["parameters"]["columns"] = 'time.source,source.ip,malware.name,status,source.as_name,source.geolocation.cc'
+            bot["parameters"]['ignore_values'] = ',,,,,'
+            changed = True
+    return changed, defaults, runtime, harmonization
+
+
+def v300_pipeline_file_removal(defaults, runtime, harmonization, dry_run):
+    """
+    Remove the pipeline.conf file
+    """
+    changed = None
+    messages = []
+    pipeline_file = Path(CONFIG_DIR) / "pipeline.conf"
+    if pipeline_file.exists():
+        pipelines = load_configuration(pipeline_file)
+        for bot in runtime:
+            if bot in pipelines:
+                if 'destination-queues' in pipelines[bot]:
+                    destination_queues = pipelines[bot]['destination-queues']
+                    if isinstance(destination_queues, dict):
+                        runtime[bot]['parameters']['destination_queues'] = destination_queues
+                    if isinstance(destination_queues, list):
+                        runtime[bot]['parameters']['destination_queues'] = {'_default': destination_queues}
+                    if isinstance(destination_queues, str):
+                        runtime[bot]['parameters']['destination_queues'] = {'_default': [destination_queues]}
+                if 'source-queue' in pipelines[bot]:
+                    if pipelines[bot]['source-queue'] != f"{bot}-queue":
+                        runtime[bot]['parameters']['source_queue'] = pipelines[bot]['source-queue']
+        if dry_run:
+            print(f'Would now remove file {pipeline_file!r}.')
+        else:
+            pipeline_file.unlink()
+        changed = True
+    messages = ' '.join(messages)
+    return messages if messages else changed, defaults, runtime, harmonization
+
+
+def v301_deprecations(defaults, runtime, harmonization, dry_run):
+    """
+    Deprecate malwaredomains parser and collector
+    """
+    found_malwaredomainsparser = []
+    found_malwaredomainscollector = []
+    changed = None
+    messages = []
+    for bot_id, bot in runtime.items():
+        if bot["module"] == "intelmq.bots.parsers.malwaredomains.parser":
+            found_malwaredomainsparser.append(bot_id)
+        if bot["module"] == "intelmq.bots.collectors.http.collector":
+            if "http_url" not in bot["parameters"]:
+                continue
+            if bot["parameters"]["http_url"] == 'http://mirror1.malwaredomains.com/files/domains.txt':
+                found_malwaredomainscollector.append(bot_id)
+    if found_malwaredomainsparser:
+        messages.append('A discontinued bot "Malware Domains Parser" has been found '
+                        'as bot %s.' % ', '.join(sorted(found_malwaredomainsparser)))
+    if found_malwaredomainscollector:
+        messages.append('A discontinued bot "Malware Domains Collector" has been found '
+                        'as bot %s.' % ', '.join(sorted(found_malwaredomainscollector)))
+    messages = ' '.join(messages)
+    return messages + ' Remove affected bots yourself.' if messages else changed, defaults, runtime, harmonization
+
+
 UPGRADES = OrderedDict([
     ((1, 0, 0, 'dev7'), (v100_dev7_modify_syntax, )),
     ((1, 1, 0), (v110_shadowserver_feednames, v110_deprecations)),
@@ -591,6 +709,9 @@ UPGRADES = OrderedDict([
     ((2, 3, 0), (v230_csv_parser_parameter_fix, v230_feed_changes, v230_deprecations,)),
     ((2, 3, 1), ()),
     ((2, 3, 2), ()),
+    ((2, 3, 3), (v233_feodotracker_browse, )),
+    ((3, 0, 0), (v300_bots_file_removal, v300_defaults_file_removal, v300_pipeline_file_removal, )),
+    ((3, 0, 1), (v301_deprecations, )),
 ])
 
 ALWAYS = (harmonization, )
