@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2019 Guillermo Rodriguez
+#
+# SPDX-License-Identifier: AGPL-3.0-or-later
+
 # -*- coding: utf-8 -*-
 
 import os
@@ -19,7 +23,7 @@ EXAMPLE_REPORT = {"feed.name": "ShadowServer Drone",
                   }
 EVENTS = [{'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.asn': 8560,
            'destination.geolocation.cc': 'US',
@@ -46,7 +50,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:05+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.fqdn': '015.example.com',
            'destination.geolocation.cc': 'NL',
@@ -69,7 +73,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:08+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.asn': 8560,
            'destination.geolocation.cc': 'DE',
@@ -93,7 +97,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:10+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.asn': 8560,
            'destination.geolocation.cc': 'DE',
@@ -118,7 +122,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:15+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.asn': 8560,
            'destination.geolocation.cc': 'US',
@@ -147,7 +151,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:26+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.asn': 8560,
            'destination.geolocation.cc': 'DE',
@@ -171,7 +175,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:28+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.asn': 8560,
            'destination.geolocation.cc': 'DE',
@@ -197,7 +201,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:29+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'malicious code',
+           'classification.taxonomy': 'malicious-code',
            'classification.type': 'infected-system',
            'destination.asn': 8560,
            'destination.geolocation.cc': 'US',
@@ -225,7 +229,7 @@ EVENTS = [{'__type': 'Event',
            'time.source': '2011-04-23T00:00:33+00:00'},
           {'__type': 'Event',
            'feed.name': 'ShadowServer Drone',
-           'classification.taxonomy': 'abusive content',
+           'classification.taxonomy': 'abusive-content',
            'classification.type': 'spam',
            'classification.identifier': 'spam',
            'protocol.transport': 'tcp',
